\name{csys.add.algorithm}
\alias{csys.add.algorithm}
\title{Add an algorithm to the supported algorithms list}
\Description{
  This function is used to add a new algorithm (format: list) to the
  given algorithms data frame. The algorithm list can be generated by
  calling csys.make.algorithm(...).

  The function returns a new data.frame with new algorithm added.
}
\usage{
csys.add.algorithm(algorithm, algos = NULL)
}

\arguments{
  \item{algorithm}{a list which should have the following tags:
    $name: the algorithm name.
    $package: the algorithm package name which will be load
    when the algorithm function is called.
    $func.name: the algorithm function name.
    $pass.argument: indicates whether pass the rest arguments (i.e.:
    "...")to the algorithm function. Its value should be either "TRUE" or
    "FALSE". ex: if the value is TRUE, $func.name = algo_func and there
    is no other specified parameters, then algo_func(...) will be called.
    $train.name: the data parameter name which will be used in a call of
    algorithm function.ex: if $train.name = data and $func.name =
    algo_func, then algo_func(data = some_data) will be called.
    $cbind: whether calls cbind(label,data). Its value should be either
    "TRUE" or "FALSE".
    $data.frame: whether data is passed as a data.frame. Its value
    should be either "TRUE" or "FALSE".
    $labels.name: the label parameter name which will be used in a call of
    algorithm function.ex: if $label = formula and $func.name =
    algo_func, then algo_func(formula = some_labels) will be called.
    $labels.formula.left: indicates what should be the left formula part
    if the labels is passed as a formula. For example: "labels ~ .".
    $labels.formula.right: indicates what should be the right formula part
    if the labels is passed as a formula. For example: "labels ~ .".
  }
  \item{algos}{the current supported algorithms in the data.frame format.}
}

\seealso{
   \code{\link{csys.make.algorithm} , \link{csys.load.algorithm}}.
}
\examples{
## create a new algorithm, see csys.make.algorithm help page for more details
algorithm = csys.make.algorithm(...);

## create a supported algorithms data frame
algos = csys.add.algorithm(algorithm);
}
\keyword{csys.add.algorithm, algorithm}
